Programas gráficos — titulo...

# Programas gráficos

Los programas gráficos son aquellos que pueden interactuar con los usuarios usando botones, ventanas, campos de texto etc.

## Nuestro primer ejemplo

Comencemos haciendo un programa sencillo.

Vamos a crear un programa que simplemente muestre un mensaje de bienvenida:

    avisar("Bienvenido a patin !!!")

Ahora, tenemos que hacer `click` en el código que aparece mas arriba y luego pulsar el botón `ejecutar`.

Lo que vamos a ver inmediatamente es el mensaje de saludo: